.. _session_toplevel:

=================
Using the Session
=================

.. module:: sqlalchemy.orm.session

The declarative base and ORM mapping functions described at
:ref:`mapper_config_toplevel` are the primary configurational interface for the
ORM. Once mappings are configured, the primary usage interface for
persistence operations is the
:class:`.Session`.

.. toctree::
    :maxdepth: 3

    session_basics
    session_state_management
    cascades
    session_transaction
    persistence_techniques
    contextual
    session_events
    session_api


